#Quantitative Fisheries Center
#R Short course
#Simple linear regression 3

#Read in data
reg.data<-read.table("C:\\Documents and Settings\\wagnerty\\My Documents\\R-SHORT\\Programs\\5_Linear regression\\Chinook salmon data.txt", na.strings="NA",header=T)

#Perform regression only on Dworshak hatchery fish
dwor.reg <- lm(length ~ wgt, subset=hatchery=="DWOR", data=reg.data)
summary(dwor.reg)
anova.lm(dwor.reg)

#Perform regression on those fish less than 140 mm
length.reg <- lm(length ~ wgt, subset=length < 140, data=reg.data)
summary(length.reg)
#Plot the model fit
plot(length~wgt, subset=length < 140, data=reg.data)
abline(lm(length ~ wgt, subset=length < 140, data=reg.data))


########## EXAMPLE of running a model through a loop ####################
#Regressions by grouping factors, using a loop
#Create a new variable called hatch and set to zero
reg.data$hatch<-0
#Re-code the three hatcheries into a numeric
reg.data[1:30,6]<-1
reg.data[31:60,6]<-2
reg.data[61:90,6]<-3

#Or we can use an ifelse statement
#ifelse syntax is: ifelse(test, yes, no)
reg.data$hatch<-ifelse(reg.data$hatchery=="DWOR", 1, ifelse(reg.data$hatchery=="MCCA", 2,3))

#Create an empty list to fill during the loop
model<-list()
#Loop through hatcheries. Note, we use double brackets to index a list
for(i in 1:3){
	model[[i]]<-lm(length~wgt, subset=hatch==i, data=reg.data)
	print("Model")
	print(i)
	print(summary(model[[i]]))
}

#Run a model through a loop and plot
#Create an empty list to fill during the loop
model<-list()  
par(mfrow=c(2,2),mar=c(5,5,2,5))  #Adjust plotting window
h<-c('DWOR','MCCA','RAPH') #Create a vector of hathery names to use in plot command below
#Loop through hatcheries. Note, we use double brackets to index a list
for(i in 1:3){
	model[[i]]<-lm(length~wgt, subset=hatch==i, data=reg.data) 
	a<-paste('Linear regression model', (i), 'summary')  #Use the paste command to create a text to output
	print(a)							     #Print the above text to the console
	cat('Linear regression using the cat function for model', i, 'summary') #Use the cat function to print text and numbers to console                                          
	print(summary(model[[i]]))                           #Print the summary of each model
	plot(length~wgt,subset=hatch==i,data=reg.data,main=paste('This is hatchery',h[i]),
	col=i, pch=i)
}


######Yet another approach########
#Looping through text (character) fields instead of re-coding
#the hatcheries into numeric values

for(i in c('DWOR','MCCA','RAPH')){   
	model<-lm(length~wgt, subset=hatchery==i, data=reg.data)  #Notice we are not filling a list here
	a<-paste('Linear regression model for', (i), 'hatchery')  #Use the paste command to create text to output
	print(a)                                                  #Print the above text to the console
	print(summary(model))                                     #Print the summary of each model
}



