#Quantitative Fisheries Center
#R short-course
#Nonlinear regression example

#These data are from a spring gill net survey of lake trout in the Great Lakes conducted by the Michigan Department of Natural Resources

length.age<-read.table("C:\\Documents and Settings\\wagnerty\\My Documents\\R-SHORT\\Programs\\7_NonlinearRegression\\non linear reg data-length-weight-age.txt", header=TRUE)



#Nonlinear regression - Model for length at age
#Fit a von Bertalanffy Growth Model

vonB1<-nls(length~Linf*(1-exp(-k*(age-to))), data=length.age, start=list(Linf=1000, k=0.05, to=-2))
summary(vonB1)

#95% Confidence intervals for parameters
library(MASS) #Must have MASS package loaded
confint(vonB1,level = 0.95)


#Create a sequence of ages from 0 to 16 by 1
age2<-seq(0,16,1)
#Predict the lengths using estimated parameters
y1<-1247.537*(1-exp(-0.06164*(age2--4.6745)))
#Plot original data points
plot(length~age, data=length.age, xlim=c(0,17), pch=16, xlab="Age (yrs)", ylab="Length (mm)",cex.lab=1.5, cex.axis=1.5)
#Overlay predicted values form models
lines(age2,y1)
text(4,850,expression(paste(L[t],'=',L[infinity](1-plain(e)^-k(t-t[0])) , '+ error')),cex=1.5)




